# Python SDK for OpsGenie Web/REST API

[![Build Status](https://travis-ci.org/criteo-forks/opsgenie-python-sdk.svg?branch=master)](https://travis-ci.org/criteo-forks/opsgenie-python-sdk)

OpsGenie OpenAPI Specification

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 2.0.0
- Package version: 1.0.7
- Build package: io.swagger.codegen.languages.PythonClientCodegen

This is generated from https://github.com/iksaif/opsgenie-oas using https://github.com/opsgenie/opsgenie-oas/pull/35

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/criteo-forks/opsgenie-python-sdk.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/criteo-forks/opsgenie-python-sdk.git`)

Then import the package:
```python
import opsgenie_swagger
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import opsgenie_swagger
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import opsgenie_swagger
from opsgenie_swagger.rest import ApiException
from pprint import pprint

# Configure API key authorization: GenieKey
opsgenie_swagger.configuration.api_key['Authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# opsgenie_swagger.configuration.api_key_prefix['Authorization'] = 'Bearer'
# create an instance of the API class
api_instance = opsgenie_swagger.AccountApi()

try:
    # Get Account Info
    api_response = api_instance.get_info()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling AccountApi->get_info: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.opsgenie.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountApi* | [**get_info**](docs/AccountApi.md#get_info) | **GET** /v2/account | Get Account Info
*AlertApi* | [**acknowledge_alert**](docs/AlertApi.md#acknowledge_alert) | **POST** /v2/alerts/{identifier}/acknowledge | Acknowledge Alert
*AlertApi* | [**add_attachment**](docs/AlertApi.md#add_attachment) | **POST** /v2/alerts/{identifier}/attachments | Add Alert Attachment
*AlertApi* | [**add_details**](docs/AlertApi.md#add_details) | **POST** /v2/alerts/{identifier}/details | Add Details
*AlertApi* | [**add_note**](docs/AlertApi.md#add_note) | **POST** /v2/alerts/{identifier}/notes | Add Note
*AlertApi* | [**add_responder**](docs/AlertApi.md#add_responder) | **POST** /v2/alerts/{identifier}/responders | Add Responder
*AlertApi* | [**add_tags**](docs/AlertApi.md#add_tags) | **POST** /v2/alerts/{identifier}/tags | Add Tags
*AlertApi* | [**add_team**](docs/AlertApi.md#add_team) | **POST** /v2/alerts/{identifier}/teams | Add Team
*AlertApi* | [**assign_alert**](docs/AlertApi.md#assign_alert) | **POST** /v2/alerts/{identifier}/assign | Assign Alert
*AlertApi* | [**close_alert**](docs/AlertApi.md#close_alert) | **POST** /v2/alerts/{identifier}/close | Close Alert
*AlertApi* | [**create_alert**](docs/AlertApi.md#create_alert) | **POST** /v2/alerts | Create Alert
*AlertApi* | [**create_saved_searches**](docs/AlertApi.md#create_saved_searches) | **POST** /v2/alerts/saved-searches | Create Saved Search
*AlertApi* | [**delete_alert**](docs/AlertApi.md#delete_alert) | **DELETE** /v2/alerts/{identifier} | Delete Alert
*AlertApi* | [**delete_saved_search**](docs/AlertApi.md#delete_saved_search) | **DELETE** /v2/alerts/saved-searches/{identifier} | Delete Saved Search
*AlertApi* | [**escalate_alert**](docs/AlertApi.md#escalate_alert) | **POST** /v2/alerts/{identifier}/escalate | Escalate Alert
*AlertApi* | [**execute_custom_alert_action**](docs/AlertApi.md#execute_custom_alert_action) | **POST** /v2/alerts/{identifier}/actions/{actionName} | Custom Alert Action
*AlertApi* | [**get_alert**](docs/AlertApi.md#get_alert) | **GET** /v2/alerts/{identifier} | Get Alert
*AlertApi* | [**get_attachment**](docs/AlertApi.md#get_attachment) | **GET** /v2/alerts/{identifier}/attachments/{attachmentId} | Get Alert Attachment
*AlertApi* | [**get_request_status**](docs/AlertApi.md#get_request_status) | **GET** /v2/alerts/requests/{requestId} | Get Request Status of Alert
*AlertApi* | [**get_saved_search**](docs/AlertApi.md#get_saved_search) | **GET** /v2/alerts/saved-searches/{identifier} | Get Saved Search
*AlertApi* | [**list_alerts**](docs/AlertApi.md#list_alerts) | **GET** /v2/alerts | List Alerts
*AlertApi* | [**list_attachments**](docs/AlertApi.md#list_attachments) | **GET** /v2/alerts/{identifier}/attachments | List Alert Attachments
*AlertApi* | [**list_logs**](docs/AlertApi.md#list_logs) | **GET** /v2/alerts/{identifier}/logs | List Alert Logs
*AlertApi* | [**list_notes**](docs/AlertApi.md#list_notes) | **GET** /v2/alerts/{identifier}/notes | List Alert Notes
*AlertApi* | [**list_recipients**](docs/AlertApi.md#list_recipients) | **GET** /v2/alerts/{identifier}/recipients | List Alert Recipients
*AlertApi* | [**list_saved_searches**](docs/AlertApi.md#list_saved_searches) | **GET** /v2/alerts/saved-searches | Lists Saved Searches
*AlertApi* | [**remove_attachment**](docs/AlertApi.md#remove_attachment) | **DELETE** /v2/alerts/{identifier}/attachments/{attachmentId} | Remove Alert Attachment
*AlertApi* | [**remove_details**](docs/AlertApi.md#remove_details) | **DELETE** /v2/alerts/{identifier}/details | Remove Details
*AlertApi* | [**remove_tags**](docs/AlertApi.md#remove_tags) | **DELETE** /v2/alerts/{identifier}/tags | Remove Tags
*AlertApi* | [**snooze_alert**](docs/AlertApi.md#snooze_alert) | **POST** /v2/alerts/{identifier}/snooze | Snooze Alert
*AlertApi* | [**un_acknowledge_alert**](docs/AlertApi.md#un_acknowledge_alert) | **POST** /v2/alerts/{identifier}/unacknowledge | UnAcknowledge Alert
*ContactApi* | [**create_contact**](docs/ContactApi.md#create_contact) | **POST** /v2/users/{identifier}/contacts | Create Contact
*ContactApi* | [**delete_contact**](docs/ContactApi.md#delete_contact) | **DELETE** /v2/users/{identifier}/contacts/{contactId} | Delete Contact
*ContactApi* | [**disable_contact**](docs/ContactApi.md#disable_contact) | **POST** /v2/users/{identifier}/contacts/{contactId}/disable | Disable Contact
*ContactApi* | [**enable_contact**](docs/ContactApi.md#enable_contact) | **POST** /v2/users/{identifier}/contacts/{contactId}/enable | Enable Contact
*ContactApi* | [**get_contact**](docs/ContactApi.md#get_contact) | **GET** /v2/users/{identifier}/contacts/{contactId} | Get Contact
*ContactApi* | [**list_contacts**](docs/ContactApi.md#list_contacts) | **GET** /v2/users/{identifier}/contacts | List Contacts
*ContactApi* | [**update_contact**](docs/ContactApi.md#update_contact) | **PATCH** /v2/users/{identifier}/contacts/{contactId} | Update Contact (Partial)
*CustomUserRoleApi* | [**create_custom_user_role**](docs/CustomUserRoleApi.md#create_custom_user_role) | **POST** /v2/roles | Create Custom User Role
*CustomUserRoleApi* | [**delete_custom_user_role**](docs/CustomUserRoleApi.md#delete_custom_user_role) | **DELETE** /v2/roles/{identifier} | Delete Custom User Role
*CustomUserRoleApi* | [**get_custom_user_role**](docs/CustomUserRoleApi.md#get_custom_user_role) | **GET** /v2/roles/{identifier} | Get Custom User Role
*CustomUserRoleApi* | [**list_custom_user_roles**](docs/CustomUserRoleApi.md#list_custom_user_roles) | **GET** /v2/roles | List Custom User Roles
*CustomUserRoleApi* | [**update_custom_user_role**](docs/CustomUserRoleApi.md#update_custom_user_role) | **PUT** /v2/roles/{identifier} | Update Custom User Role
*DeprecatedPolicyApi* | [**change_alert_policy_order**](docs/DeprecatedPolicyApi.md#change_alert_policy_order) | **POST** /v1/policies/{policyId}/change-order | Change Alert Policy Order
*DeprecatedPolicyApi* | [**create_alert_policy**](docs/DeprecatedPolicyApi.md#create_alert_policy) | **POST** /v1/policies | Create Alert Policy
*DeprecatedPolicyApi* | [**delete_alert_policy**](docs/DeprecatedPolicyApi.md#delete_alert_policy) | **DELETE** /v1/policies/{policyId} | Delete Alert Policy
*DeprecatedPolicyApi* | [**disable_alert_policy**](docs/DeprecatedPolicyApi.md#disable_alert_policy) | **POST** /v1/policies/{policyId}/disable | Disable Alert Policy
*DeprecatedPolicyApi* | [**enable_alert_policy**](docs/DeprecatedPolicyApi.md#enable_alert_policy) | **POST** /v1/policies/{policyId}/enable | Enable Alert Policy
*DeprecatedPolicyApi* | [**get_alert_policy**](docs/DeprecatedPolicyApi.md#get_alert_policy) | **GET** /v1/policies/{policyId} | Get Alert Policy
*DeprecatedPolicyApi* | [**list_alert_policies**](docs/DeprecatedPolicyApi.md#list_alert_policies) | **GET** /v1/policies | List Alert Policies
*DeprecatedPolicyApi* | [**update_alert_policy**](docs/DeprecatedPolicyApi.md#update_alert_policy) | **PUT** /v1/policies/{policyId} | Update Alert Policy
*EscalationApi* | [**create_escalation**](docs/EscalationApi.md#create_escalation) | **POST** /v2/escalations | Create Escalation
*EscalationApi* | [**delete_escalation**](docs/EscalationApi.md#delete_escalation) | **DELETE** /v2/escalations/{identifier} | Delete Escalation
*EscalationApi* | [**get_escalation**](docs/EscalationApi.md#get_escalation) | **GET** /v2/escalations/{identifier} | Get Escalation
*EscalationApi* | [**list_escalations**](docs/EscalationApi.md#list_escalations) | **GET** /v2/escalations | List Escalations
*EscalationApi* | [**update_escalation**](docs/EscalationApi.md#update_escalation) | **PATCH** /v2/escalations/{identifier} | Update Escalation (Partial)
*ForwardingRuleApi* | [**create_forwarding_rule**](docs/ForwardingRuleApi.md#create_forwarding_rule) | **POST** /v2/forwarding-rules | Create Forwarding Rule
*ForwardingRuleApi* | [**delete_forwarding_rule**](docs/ForwardingRuleApi.md#delete_forwarding_rule) | **DELETE** /v2/forwarding-rules/{identifier} | Delete Forwarding Rule
*ForwardingRuleApi* | [**get_forwarding_rule**](docs/ForwardingRuleApi.md#get_forwarding_rule) | **GET** /v2/forwarding-rules/{identifier} | Get Forwarding Rule
*ForwardingRuleApi* | [**list_forwarding_rules**](docs/ForwardingRuleApi.md#list_forwarding_rules) | **GET** /v2/forwarding-rules | List Forwarding Rules
*ForwardingRuleApi* | [**update_forwarding_rule**](docs/ForwardingRuleApi.md#update_forwarding_rule) | **PUT** /v2/forwarding-rules/{identifier} | Update Forwarding Rule
*HeartbeatApi* | [**create_heartbeat**](docs/HeartbeatApi.md#create_heartbeat) | **POST** /v2/heartbeats | Create Heartbeat
*HeartbeatApi* | [**delete_heartbeat**](docs/HeartbeatApi.md#delete_heartbeat) | **DELETE** /v2/heartbeats/{name} | Delete Heartbeat
*HeartbeatApi* | [**disable_heartbeat**](docs/HeartbeatApi.md#disable_heartbeat) | **POST** /v2/heartbeats/{name}/disable | Disable Heartbeat
*HeartbeatApi* | [**enable_heartbeat**](docs/HeartbeatApi.md#enable_heartbeat) | **POST** /v2/heartbeats/{name}/enable | Enable Heartbeat
*HeartbeatApi* | [**get_heartbeat**](docs/HeartbeatApi.md#get_heartbeat) | **GET** /v2/heartbeats/{name} | Get Heartbeat
*HeartbeatApi* | [**ping**](docs/HeartbeatApi.md#ping) | **GET** /v2/heartbeats/{name}/ping | Ping Heartbeat
*HeartbeatApi* | [**update_heartbeat**](docs/HeartbeatApi.md#update_heartbeat) | **PATCH** /v2/heartbeats/{name} | Update Heartbeat (Partial)
*IntegrationApi* | [**authenticate_integration**](docs/IntegrationApi.md#authenticate_integration) | **POST** /v2/integrations/authenticate | Authenticate Integration
*IntegrationApi* | [**create_integration**](docs/IntegrationApi.md#create_integration) | **POST** /v2/integrations | Create Integration
*IntegrationApi* | [**delete_integration**](docs/IntegrationApi.md#delete_integration) | **DELETE** /v2/integrations/{id} | Delete Integration
*IntegrationApi* | [**disable_integration**](docs/IntegrationApi.md#disable_integration) | **POST** /v2/integrations/{id}/disable | Disable Integration
*IntegrationApi* | [**enable_integration**](docs/IntegrationApi.md#enable_integration) | **POST** /v2/integrations/{id}/enable | Enable Integration
*IntegrationApi* | [**get_integration**](docs/IntegrationApi.md#get_integration) | **GET** /v2/integrations/{id} | Get Integration
*IntegrationApi* | [**list_integrations**](docs/IntegrationApi.md#list_integrations) | **GET** /v2/integrations | List Integrations
*IntegrationApi* | [**update_integration**](docs/IntegrationApi.md#update_integration) | **PUT** /v2/integrations/{id} | Update Integration
*IntegrationActionApi* | [**create_integration_action**](docs/IntegrationActionApi.md#create_integration_action) | **POST** /v2/integrations/{id}/actions | Create Integration Action
*IntegrationActionApi* | [**list_integration_actions**](docs/IntegrationActionApi.md#list_integration_actions) | **GET** /v2/integrations/{id}/actions | List Integration Actions
*IntegrationActionApi* | [**update_integration_actions**](docs/IntegrationActionApi.md#update_integration_actions) | **PUT** /v2/integrations/{id}/actions | Update Integration Actions
*MaintenanceApi* | [**cancel_maintenance**](docs/MaintenanceApi.md#cancel_maintenance) | **POST** /v1/maintenance/{id}/cancel | Cancel Maintenance
*MaintenanceApi* | [**create_maintenance**](docs/MaintenanceApi.md#create_maintenance) | **POST** /v1/maintenance | Create Maintenance
*MaintenanceApi* | [**delete_maintenance**](docs/MaintenanceApi.md#delete_maintenance) | **DELETE** /v1/maintenance/{id} | Delete Maintenance
*MaintenanceApi* | [**get_maintenance**](docs/MaintenanceApi.md#get_maintenance) | **GET** /v1/maintenance/{id} | Get Maintenance
*MaintenanceApi* | [**list_maintenance**](docs/MaintenanceApi.md#list_maintenance) | **GET** /v1/maintenance | List Maintenance
*MaintenanceApi* | [**update_maintenance**](docs/MaintenanceApi.md#update_maintenance) | **PUT** /v1/maintenance/{id} | Update Maintenance
*NotificationRuleApi* | [**change_notification_rule_order**](docs/NotificationRuleApi.md#change_notification_rule_order) | **POST** /v2/users/{identifier}/notification-rules/{ruleId}/change-order | Change order of Notification Rule
*NotificationRuleApi* | [**create_notification_rule**](docs/NotificationRuleApi.md#create_notification_rule) | **POST** /v2/users/{identifier}/notification-rules | Create Notification Rule
*NotificationRuleApi* | [**delete_notification_rule**](docs/NotificationRuleApi.md#delete_notification_rule) | **DELETE** /v2/users/{identifier}/notification-rules/{ruleId} | Delete Notification Rule
*NotificationRuleApi* | [**disable_notification_rule**](docs/NotificationRuleApi.md#disable_notification_rule) | **POST** /v2/users/{identifier}/notification-rules/{ruleId}/disable | Disable Notification Rule
*NotificationRuleApi* | [**enable_notification_rule**](docs/NotificationRuleApi.md#enable_notification_rule) | **POST** /v2/users/{identifier}/notification-rules/{ruleId}/enable | Enable Notification Rule
*NotificationRuleApi* | [**get_notification_rule**](docs/NotificationRuleApi.md#get_notification_rule) | **GET** /v2/users/{identifier}/notification-rules/{ruleId} | Get Notification Rule
*NotificationRuleApi* | [**list_notification_rules**](docs/NotificationRuleApi.md#list_notification_rules) | **GET** /v2/users/{identifier}/notification-rules | List Notification Rules
*NotificationRuleApi* | [**update_notification_rule**](docs/NotificationRuleApi.md#update_notification_rule) | **PATCH** /v2/users/{identifier}/notification-rules/{ruleId} | Update Notification Rule (Partial)
*NotificationRuleStepApi* | [**create_notification_rule_step**](docs/NotificationRuleStepApi.md#create_notification_rule_step) | **POST** /v2/users/{identifier}/notification-rules/{ruleId}/steps | Create Notification Rule Step
*NotificationRuleStepApi* | [**delete_notification_rule_step**](docs/NotificationRuleStepApi.md#delete_notification_rule_step) | **DELETE** /v2/users/{identifier}/notification-rules/{ruleId}/steps/{id} | Delete Notification Rule Step
*NotificationRuleStepApi* | [**disable_notification_rule_step**](docs/NotificationRuleStepApi.md#disable_notification_rule_step) | **POST** /v2/users/{identifier}/notification-rules/{ruleId}/steps/{id}/disable | Disable Notification Rule Step
*NotificationRuleStepApi* | [**enable_notification_rule_step**](docs/NotificationRuleStepApi.md#enable_notification_rule_step) | **POST** /v2/users/{identifier}/notification-rules/{ruleId}/steps/{id}/enable | Enable Notification Rule Step
*NotificationRuleStepApi* | [**get_notification_rule_step**](docs/NotificationRuleStepApi.md#get_notification_rule_step) | **GET** /v2/users/{identifier}/notification-rules/{ruleId}/steps/{id} | Get Notification Rule Step
*NotificationRuleStepApi* | [**list_notification_rule_steps**](docs/NotificationRuleStepApi.md#list_notification_rule_steps) | **GET** /v2/users/{identifier}/notification-rules/{ruleId}/steps | List Notification Rule Steps
*NotificationRuleStepApi* | [**update_notification_rule_step**](docs/NotificationRuleStepApi.md#update_notification_rule_step) | **PATCH** /v2/users/{identifier}/notification-rules/{ruleId}/steps/{id} | Update Notification Rule Step (Partial)
*PolicyApi* | [**change_policy_order**](docs/PolicyApi.md#change_policy_order) | **POST** /v2/policies/{policyId}/change-order | Change Policy Order
*PolicyApi* | [**create_policy**](docs/PolicyApi.md#create_policy) | **POST** /v2/policies | Create Policy
*PolicyApi* | [**delete_policy**](docs/PolicyApi.md#delete_policy) | **DELETE** /v2/policies/{policyId} | Delete Policy
*PolicyApi* | [**disable_policy**](docs/PolicyApi.md#disable_policy) | **POST** /v2/policies/{policyId}/disable | Disable Policy
*PolicyApi* | [**enable_policy**](docs/PolicyApi.md#enable_policy) | **POST** /v2/policies/{policyId}/enable | Enable Policy
*PolicyApi* | [**get_policy**](docs/PolicyApi.md#get_policy) | **GET** /v2/policies/{policyId} | Get Policy
*PolicyApi* | [**list_alert_policies**](docs/PolicyApi.md#list_alert_policies) | **GET** /v2/policies/alert | List Alert Policies
*PolicyApi* | [**list_notification_policies**](docs/PolicyApi.md#list_notification_policies) | **GET** /v2/policies/notification | List Notification Policies
*PolicyApi* | [**update_policy**](docs/PolicyApi.md#update_policy) | **PUT** /v2/policies/{policyId} | Update Policy
*ScheduleApi* | [**create_schedule**](docs/ScheduleApi.md#create_schedule) | **POST** /v2/schedules | Create Schedule
*ScheduleApi* | [**delete_schedule**](docs/ScheduleApi.md#delete_schedule) | **DELETE** /v2/schedules/{identifier} | Delete Schedule
*ScheduleApi* | [**export_schedule**](docs/ScheduleApi.md#export_schedule) | **GET** /v2/schedules/{identifier}.ics | Export Schedule
*ScheduleApi* | [**get_schedule**](docs/ScheduleApi.md#get_schedule) | **GET** /v2/schedules/{identifier} | Get Schedule
*ScheduleApi* | [**get_schedule_timeline**](docs/ScheduleApi.md#get_schedule_timeline) | **GET** /v2/schedules/{identifier}/timeline | Get Schedule Timeline
*ScheduleApi* | [**list_schedules**](docs/ScheduleApi.md#list_schedules) | **GET** /v2/schedules | List Schedules
*ScheduleApi* | [**update_schedule**](docs/ScheduleApi.md#update_schedule) | **PATCH** /v2/schedules/{identifier} | Update Schedule (Partial)
*ScheduleOverrideApi* | [**create_schedule_override**](docs/ScheduleOverrideApi.md#create_schedule_override) | **POST** /v2/schedules/{identifier}/overrides | Create Schedule Override
*ScheduleOverrideApi* | [**delete_schedule_override**](docs/ScheduleOverrideApi.md#delete_schedule_override) | **DELETE** /v2/schedules/{identifier}/overrides/{alias} | Delete Schedule Override
*ScheduleOverrideApi* | [**get_schedule_override**](docs/ScheduleOverrideApi.md#get_schedule_override) | **GET** /v2/schedules/{identifier}/overrides/{alias} | Get Schedule Override
*ScheduleOverrideApi* | [**list_schedule_override**](docs/ScheduleOverrideApi.md#list_schedule_override) | **GET** /v2/schedules/{identifier}/overrides | List Schedule Overrides
*ScheduleOverrideApi* | [**update_schedule_override**](docs/ScheduleOverrideApi.md#update_schedule_override) | **PUT** /v2/schedules/{identifier}/overrides/{alias} | Update Schedule Override
*ScheduleRotationApi* | [**create_schedule_rotation**](docs/ScheduleRotationApi.md#create_schedule_rotation) | **POST** /v2/schedules/{identifier}/rotations | Create Schedule Rotation
*ScheduleRotationApi* | [**delete_schedule_rotation**](docs/ScheduleRotationApi.md#delete_schedule_rotation) | **DELETE** /v2/schedules/{identifier}/rotations/{id} | Delete Schedule Rotation
*ScheduleRotationApi* | [**get_schedule_rotation**](docs/ScheduleRotationApi.md#get_schedule_rotation) | **GET** /v2/schedules/{identifier}/rotations/{id} | Get Schedule Rotation
*ScheduleRotationApi* | [**list_schedule_rotations**](docs/ScheduleRotationApi.md#list_schedule_rotations) | **GET** /v2/schedules/{identifier}/rotations | List Schedule Rotations
*ScheduleRotationApi* | [**update_schedule_rotation**](docs/ScheduleRotationApi.md#update_schedule_rotation) | **PATCH** /v2/schedules/{identifier}/rotations/{id} | Update Schedule Rotation (Partial)
*TeamApi* | [**create_team**](docs/TeamApi.md#create_team) | **POST** /v2/teams | Create Team
*TeamApi* | [**delete_team**](docs/TeamApi.md#delete_team) | **DELETE** /v2/teams/{identifier} | Delete Team
*TeamApi* | [**get_team**](docs/TeamApi.md#get_team) | **GET** /v2/teams/{identifier} | Get Team
*TeamApi* | [**list_team_logs**](docs/TeamApi.md#list_team_logs) | **GET** /v2/teams/{identifier}/logs | List Team Logs
*TeamApi* | [**list_teams**](docs/TeamApi.md#list_teams) | **GET** /v2/teams | List Teams
*TeamApi* | [**update_team**](docs/TeamApi.md#update_team) | **PATCH** /v2/teams/{identifier} | Update Team (Partial)
*TeamMemberApi* | [**add_team_member**](docs/TeamMemberApi.md#add_team_member) | **POST** /v2/teams/{identifier}/members | Add Team Member
*TeamMemberApi* | [**delete_team_member**](docs/TeamMemberApi.md#delete_team_member) | **DELETE** /v2/teams/{identifier}/members/{memberIdentifier} | Delete Team Member
*TeamRoleApi* | [**create_team_role**](docs/TeamRoleApi.md#create_team_role) | **POST** /v2/teams/{identifier}/roles | Create Team Role
*TeamRoleApi* | [**delete_team_role**](docs/TeamRoleApi.md#delete_team_role) | **DELETE** /v2/teams/{identifier}/roles/{teamRoleIdentifier} | Delete Team Role
*TeamRoleApi* | [**get_team_role**](docs/TeamRoleApi.md#get_team_role) | **GET** /v2/teams/{identifier}/roles/{teamRoleIdentifier} | Get Team Role
*TeamRoleApi* | [**list_team_roles**](docs/TeamRoleApi.md#list_team_roles) | **GET** /v2/teams/{identifier}/roles | List Team Roles
*TeamRoleApi* | [**update_team_role**](docs/TeamRoleApi.md#update_team_role) | **PATCH** /v2/teams/{identifier}/roles/{teamRoleIdentifier} | Update Team Role (Partial)
*TeamRoutingRuleApi* | [**change_team_routing_rule_order**](docs/TeamRoutingRuleApi.md#change_team_routing_rule_order) | **POST** /v2/teams/{identifier}/routing-rules/{id}/change-order | Change Team Routing Rule Order
*TeamRoutingRuleApi* | [**create_team_routing_rule**](docs/TeamRoutingRuleApi.md#create_team_routing_rule) | **POST** /v2/teams/{identifier}/routing-rules | Create Team Routing Rule
*TeamRoutingRuleApi* | [**delete_team_routing_rule**](docs/TeamRoutingRuleApi.md#delete_team_routing_rule) | **DELETE** /v2/teams/{identifier}/routing-rules/{id} | Delete Team Routing Rule
*TeamRoutingRuleApi* | [**get_team_routing_rule**](docs/TeamRoutingRuleApi.md#get_team_routing_rule) | **GET** /v2/teams/{identifier}/routing-rules/{id} | Get Team Routing Rule
*TeamRoutingRuleApi* | [**list_team_routing_rules**](docs/TeamRoutingRuleApi.md#list_team_routing_rules) | **GET** /v2/teams/{identifier}/routing-rules | List Team Routing Rules
*TeamRoutingRuleApi* | [**update_team_routing_rule**](docs/TeamRoutingRuleApi.md#update_team_routing_rule) | **PATCH** /v2/teams/{identifier}/routing-rules/{id} | Update Team Routing Rule (Partial)
*UserApi* | [**create_user**](docs/UserApi.md#create_user) | **POST** /v2/users | Create User
*UserApi* | [**delete_user**](docs/UserApi.md#delete_user) | **DELETE** /v2/users/{identifier} | Delete User
*UserApi* | [**get_user**](docs/UserApi.md#get_user) | **GET** /v2/users/{identifier} | Get User
*UserApi* | [**list_user_escalations**](docs/UserApi.md#list_user_escalations) | **GET** /v2/users/{identifier}/escalations | List User Escalations
*UserApi* | [**list_user_forwarding_rules**](docs/UserApi.md#list_user_forwarding_rules) | **GET** /v2/users/{identifier}/forwarding-rules | List User Forwarding Rules
*UserApi* | [**list_user_schedules**](docs/UserApi.md#list_user_schedules) | **GET** /v2/users/{identifier}/schedules | List User Schedules
*UserApi* | [**list_user_teams**](docs/UserApi.md#list_user_teams) | **GET** /v2/users/{identifier}/teams | List User Teams
*UserApi* | [**list_users**](docs/UserApi.md#list_users) | **GET** /v2/users | List users
*UserApi* | [**update_user**](docs/UserApi.md#update_user) | **PATCH** /v2/users/{identifier} | Update User (Partial)
*WhoIsOnCallApi* | [**export_on_call_user**](docs/WhoIsOnCallApi.md#export_on_call_user) | **GET** /v2/schedules/on-calls/{identifier}.ics | Export On-Call User
*WhoIsOnCallApi* | [**get_next_on_calls**](docs/WhoIsOnCallApi.md#get_next_on_calls) | **GET** /v2/schedules/{identifier}/next-on-calls | Get Next On Calls
*WhoIsOnCallApi* | [**get_on_calls**](docs/WhoIsOnCallApi.md#get_on_calls) | **GET** /v2/schedules/{identifier}/on-calls | Get On Calls
*WhoIsOnCallApi* | [**list_on_calls**](docs/WhoIsOnCallApi.md#list_on_calls) | **GET** /v2/schedules/on-calls | List On Calls


## Documentation For Models

 - [AccountInfo](docs/AccountInfo.md)
 - [AccountPlan](docs/AccountPlan.md)
 - [ActionCategorized](docs/ActionCategorized.md)
 - [ActionMapping](docs/ActionMapping.md)
 - [AddTeamMemberPayload](docs/AddTeamMemberPayload.md)
 - [AlertActionPayload](docs/AlertActionPayload.md)
 - [AlertAttachment](docs/AlertAttachment.md)
 - [AlertAttachmentMeta](docs/AlertAttachmentMeta.md)
 - [AlertFilter](docs/AlertFilter.md)
 - [AlertIntegration](docs/AlertIntegration.md)
 - [AlertLog](docs/AlertLog.md)
 - [AlertNote](docs/AlertNote.md)
 - [AlertPaging](docs/AlertPaging.md)
 - [AlertRecipient](docs/AlertRecipient.md)
 - [AlertReport](docs/AlertReport.md)
 - [AlertRequestStatus](docs/AlertRequestStatus.md)
 - [AlertTeamMeta](docs/AlertTeamMeta.md)
 - [AlertUserMeta](docs/AlertUserMeta.md)
 - [AuthenticateIntegrationPayload](docs/AuthenticateIntegrationPayload.md)
 - [AutoCloseAction](docs/AutoCloseAction.md)
 - [AutoRestartAction](docs/AutoRestartAction.md)
 - [BaseAlert](docs/BaseAlert.md)
 - [BaseIncomingFeature](docs/BaseIncomingFeature.md)
 - [BaseIntegrationAction](docs/BaseIntegrationAction.md)
 - [BaseResponse](docs/BaseResponse.md)
 - [CallbackCondition](docs/CallbackCondition.md)
 - [ChangeNotificationRuleOrderPayload](docs/ChangeNotificationRuleOrderPayload.md)
 - [ChangePolicyOrderPayload](docs/ChangePolicyOrderPayload.md)
 - [ChangeTeamRoutingRuleOrderPayload](docs/ChangeTeamRoutingRuleOrderPayload.md)
 - [Condition](docs/Condition.md)
 - [Contact](docs/Contact.md)
 - [ContactMeta](docs/ContactMeta.md)
 - [ContactStatus](docs/ContactStatus.md)
 - [ContactWithApplyOrder](docs/ContactWithApplyOrder.md)
 - [CreateContactPayload](docs/CreateContactPayload.md)
 - [CreateCustomUserRolePayload](docs/CreateCustomUserRolePayload.md)
 - [CreateEscalationPayload](docs/CreateEscalationPayload.md)
 - [CreateForwardingRulePayload](docs/CreateForwardingRulePayload.md)
 - [CreateHeartbeatPayload](docs/CreateHeartbeatPayload.md)
 - [CreateMaintenancePayload](docs/CreateMaintenancePayload.md)
 - [CreateNotificationRulePayload](docs/CreateNotificationRulePayload.md)
 - [CreateNotificationRuleStepPayload](docs/CreateNotificationRuleStepPayload.md)
 - [CreateSavedSearchPayload](docs/CreateSavedSearchPayload.md)
 - [CreateScheduleOverridePayload](docs/CreateScheduleOverridePayload.md)
 - [CreateSchedulePayload](docs/CreateSchedulePayload.md)
 - [CreateScheduleRotationPayload](docs/CreateScheduleRotationPayload.md)
 - [CreateTeamPayload](docs/CreateTeamPayload.md)
 - [CreateTeamRolePayload](docs/CreateTeamRolePayload.md)
 - [CreateTeamRoutingRulePayload](docs/CreateTeamRoutingRulePayload.md)
 - [CreateUserPayload](docs/CreateUserPayload.md)
 - [CustomUserRole](docs/CustomUserRole.md)
 - [DeduplicationAction](docs/DeduplicationAction.md)
 - [DelayAction](docs/DelayAction.md)
 - [DeprecatedAlertPolicy](docs/DeprecatedAlertPolicy.md)
 - [DeprecatedAlertPolicyMeta](docs/DeprecatedAlertPolicyMeta.md)
 - [DeprecatedChangeAlertPolicyOrderPayload](docs/DeprecatedChangeAlertPolicyOrderPayload.md)
 - [Duration](docs/Duration.md)
 - [Escalation](docs/Escalation.md)
 - [EscalationRepeat](docs/EscalationRepeat.md)
 - [EscalationRule](docs/EscalationRule.md)
 - [Filter](docs/Filter.md)
 - [ForwardingRule](docs/ForwardingRule.md)
 - [ForwardingRuleMeta](docs/ForwardingRuleMeta.md)
 - [Heartbeat](docs/Heartbeat.md)
 - [HeartbeatMeta](docs/HeartbeatMeta.md)
 - [Integration](docs/Integration.md)
 - [IntegrationActionFilter](docs/IntegrationActionFilter.md)
 - [IntegrationCondition](docs/IntegrationCondition.md)
 - [IntegrationMeta](docs/IntegrationMeta.md)
 - [Maintenance](docs/Maintenance.md)
 - [MaintenanceEntity](docs/MaintenanceEntity.md)
 - [MaintenanceMeta](docs/MaintenanceMeta.md)
 - [MaintenanceRule](docs/MaintenanceRule.md)
 - [MaintenanceTime](docs/MaintenanceTime.md)
 - [NextOnCall](docs/NextOnCall.md)
 - [NotificationActionType](docs/NotificationActionType.md)
 - [NotificationRepeat](docs/NotificationRepeat.md)
 - [NotificationRule](docs/NotificationRule.md)
 - [NotificationRuleMeta](docs/NotificationRuleMeta.md)
 - [NotificationRuleStep](docs/NotificationRuleStep.md)
 - [NotificationRuleStepParent](docs/NotificationRuleStepParent.md)
 - [NotifyTime](docs/NotifyTime.md)
 - [OnCall](docs/OnCall.md)
 - [OutgoingCallback](docs/OutgoingCallback.md)
 - [OutgoingCallbackNew](docs/OutgoingCallbackNew.md)
 - [PageDetails](docs/PageDetails.md)
 - [Participant](docs/Participant.md)
 - [Policy](docs/Policy.md)
 - [PolicyMeta](docs/PolicyMeta.md)
 - [Recipient](docs/Recipient.md)
 - [Responder](docs/Responder.md)
 - [SavedSearch](docs/SavedSearch.md)
 - [SavedSearchEntity](docs/SavedSearchEntity.md)
 - [SavedSearchMeta](docs/SavedSearchMeta.md)
 - [Schedule](docs/Schedule.md)
 - [ScheduleMeta](docs/ScheduleMeta.md)
 - [ScheduleOverride](docs/ScheduleOverride.md)
 - [ScheduleOverrideMeta](docs/ScheduleOverrideMeta.md)
 - [ScheduleOverrideRotation](docs/ScheduleOverrideRotation.md)
 - [ScheduleRotation](docs/ScheduleRotation.md)
 - [ScheduleTimeline](docs/ScheduleTimeline.md)
 - [SuccessData](docs/SuccessData.md)
 - [Team](docs/Team.md)
 - [TeamLog](docs/TeamLog.md)
 - [TeamLogDetails](docs/TeamLogDetails.md)
 - [TeamMember](docs/TeamMember.md)
 - [TeamMeta](docs/TeamMeta.md)
 - [TeamRight](docs/TeamRight.md)
 - [TeamRole](docs/TeamRole.md)
 - [TeamRoutingRule](docs/TeamRoutingRule.md)
 - [TimeOfDayRestriction](docs/TimeOfDayRestriction.md)
 - [TimeRestrictionInterval](docs/TimeRestrictionInterval.md)
 - [Timeline](docs/Timeline.md)
 - [TimelinePeriod](docs/TimelinePeriod.md)
 - [TimelineRecipient](docs/TimelineRecipient.md)
 - [TimelineRotation](docs/TimelineRotation.md)
 - [UpdateContactPayload](docs/UpdateContactPayload.md)
 - [UpdateCustomUserRolePayload](docs/UpdateCustomUserRolePayload.md)
 - [UpdateEscalationPayload](docs/UpdateEscalationPayload.md)
 - [UpdateForwardingRulePayload](docs/UpdateForwardingRulePayload.md)
 - [UpdateHeartbeatPayload](docs/UpdateHeartbeatPayload.md)
 - [UpdateMaintenancePayload](docs/UpdateMaintenancePayload.md)
 - [UpdateNotificationRulePayload](docs/UpdateNotificationRulePayload.md)
 - [UpdateNotificationRuleStepPayload](docs/UpdateNotificationRuleStepPayload.md)
 - [UpdateScheduleOverridePayload](docs/UpdateScheduleOverridePayload.md)
 - [UpdateSchedulePayload](docs/UpdateSchedulePayload.md)
 - [UpdateScheduleRotationPayload](docs/UpdateScheduleRotationPayload.md)
 - [UpdateTeamPayload](docs/UpdateTeamPayload.md)
 - [UpdateTeamRolePayload](docs/UpdateTeamRolePayload.md)
 - [UpdateTeamRoutingRulePayload](docs/UpdateTeamRoutingRulePayload.md)
 - [UpdateUserPayload](docs/UpdateUserPayload.md)
 - [User](docs/User.md)
 - [UserAddress](docs/UserAddress.md)
 - [UserContact](docs/UserContact.md)
 - [UserMeta](docs/UserMeta.md)
 - [UserRole](docs/UserRole.md)
 - [WeekdayTimeRestriction](docs/WeekdayTimeRestriction.md)
 - [AcknowledgeAlertPayload](docs/AcknowledgeAlertPayload.md)
 - [AddDetailsToAlertPayload](docs/AddDetailsToAlertPayload.md)
 - [AddNoteToAlertPayload](docs/AddNoteToAlertPayload.md)
 - [AddResponderToAlertPayload](docs/AddResponderToAlertPayload.md)
 - [AddTagsToAlertPayload](docs/AddTagsToAlertPayload.md)
 - [AddTeamToAlertPayload](docs/AddTeamToAlertPayload.md)
 - [AirbrakeIntegration](docs/AirbrakeIntegration.md)
 - [Alert](docs/Alert.md)
 - [AlertLogicIntegration](docs/AlertLogicIntegration.md)
 - [AlertPolicy](docs/AlertPolicy.md)
 - [AlertSiteIntegration](docs/AlertSiteIntegration.md)
 - [AllRecipient](docs/AllRecipient.md)
 - [AmazonCloudTrailIntegration](docs/AmazonCloudTrailIntegration.md)
 - [AmazonEc2AutoScalingIntegration](docs/AmazonEc2AutoScalingIntegration.md)
 - [AmazonRdsIntegration](docs/AmazonRdsIntegration.md)
 - [AmazonRoute53HealthCheckIntegration](docs/AmazonRoute53HealthCheckIntegration.md)
 - [AmazonSesIntegration](docs/AmazonSesIntegration.md)
 - [AmazonSnsCallback](docs/AmazonSnsCallback.md)
 - [AmazonSnsIntegration](docs/AmazonSnsIntegration.md)
 - [AmazonSnsOutgoingIntegration](docs/AmazonSnsOutgoingIntegration.md)
 - [ApiIntegration](docs/ApiIntegration.md)
 - [ApicaIntegration](docs/ApicaIntegration.md)
 - [ApimetricsIntegration](docs/ApimetricsIntegration.md)
 - [AppDynamicsIntegration](docs/AppDynamicsIntegration.md)
 - [AppOpticsIntegration](docs/AppOpticsIntegration.md)
 - [AppSignalIntegration](docs/AppSignalIntegration.md)
 - [AppSignalV2Integration](docs/AppSignalV2Integration.md)
 - [AssignAlertPayload](docs/AssignAlertPayload.md)
 - [AtatusIntegration](docs/AtatusIntegration.md)
 - [AtlassianBambooIntegration](docs/AtlassianBambooIntegration.md)
 - [AutoTaskEmailIntegration](docs/AutoTaskEmailIntegration.md)
 - [AutotaskAEMEmailIntegration](docs/AutotaskAEMEmailIntegration.md)
 - [AzureAutoScaleIntegration](docs/AzureAutoScaleIntegration.md)
 - [AzureIntegration](docs/AzureIntegration.md)
 - [AzureOMSIntegration](docs/AzureOMSIntegration.md)
 - [AzureResourceHealthIntegration](docs/AzureResourceHealthIntegration.md)
 - [AzureServiceHealthIntegration](docs/AzureServiceHealthIntegration.md)
 - [BMCFootPrintsV11Integration](docs/BMCFootPrintsV11Integration.md)
 - [BMCFootPrintsV12Integration](docs/BMCFootPrintsV12Integration.md)
 - [BMCRemedyForceIntegration](docs/BMCRemedyForceIntegration.md)
 - [BMCRemedyIntegration](docs/BMCRemedyIntegration.md)
 - [BMCRemedyOnDemandCallback](docs/BMCRemedyOnDemandCallback.md)
 - [BMCRemedyOnDemandIntegration](docs/BMCRemedyOnDemandIntegration.md)
 - [BaseResponseWithExpandable](docs/BaseResponseWithExpandable.md)
 - [BaseWebhookCallback](docs/BaseWebhookCallback.md)
 - [BidirectionalCallback](docs/BidirectionalCallback.md)
 - [BidirectionalCallbackNew](docs/BidirectionalCallbackNew.md)
 - [BigPandaIntegration](docs/BigPandaIntegration.md)
 - [BitbucketIntegration](docs/BitbucketIntegration.md)
 - [BlueMatadorIntegration](docs/BlueMatadorIntegration.md)
 - [BoundaryIntegration](docs/BoundaryIntegration.md)
 - [CampfireCallback](docs/CampfireCallback.md)
 - [CampfireIntegration](docs/CampfireIntegration.md)
 - [CatchpointIntegration](docs/CatchpointIntegration.md)
 - [CheckMKIntegration](docs/CheckMKIntegration.md)
 - [CherwellIntegration](docs/CherwellIntegration.md)
 - [CircleCiIntegration](docs/CircleCiIntegration.md)
 - [CirconusIntegration](docs/CirconusIntegration.md)
 - [CloseAlertPayload](docs/CloseAlertPayload.md)
 - [CloudMonixIntegration](docs/CloudMonixIntegration.md)
 - [CloudSploitIntegration](docs/CloudSploitIntegration.md)
 - [CloudWatchEventsIntegration](docs/CloudWatchEventsIntegration.md)
 - [CloudWatchIntegration](docs/CloudWatchIntegration.md)
 - [CodeshipIntegration](docs/CodeshipIntegration.md)
 - [CommonIntegrationAction](docs/CommonIntegrationAction.md)
 - [ComposeIntegration](docs/ComposeIntegration.md)
 - [ConnectWiseAutomateIntegration](docs/ConnectWiseAutomateIntegration.md)
 - [ConnectWiseIntegration](docs/ConnectWiseIntegration.md)
 - [ConnectWiseManageIntegration](docs/ConnectWiseManageIntegration.md)
 - [ConnectWiseManageV2Integration](docs/ConnectWiseManageV2Integration.md)
 - [ConsulIntegration](docs/ConsulIntegration.md)
 - [CopperEggIntegration](docs/CopperEggIntegration.md)
 - [CrashlyticsIntegration](docs/CrashlyticsIntegration.md)
 - [CreateAlertPayload](docs/CreateAlertPayload.md)
 - [CreateForwardingRuleResponse](docs/CreateForwardingRuleResponse.md)
 - [CreateHeartbeatResponse](docs/CreateHeartbeatResponse.md)
 - [CreateIntegrationActionsResponse](docs/CreateIntegrationActionsResponse.md)
 - [CreateIntegrationResponse](docs/CreateIntegrationResponse.md)
 - [CreateMaintenanceResponse](docs/CreateMaintenanceResponse.md)
 - [CreateNotificationRuleResponse](docs/CreateNotificationRuleResponse.md)
 - [CreatePolicyResponse](docs/CreatePolicyResponse.md)
 - [CreateSavedSearchResponse](docs/CreateSavedSearchResponse.md)
 - [CreateScheduleOverrideResponse](docs/CreateScheduleOverrideResponse.md)
 - [CreateScheduleResponse](docs/CreateScheduleResponse.md)
 - [DatadogIntegration](docs/DatadogIntegration.md)
 - [DataloopIOIntegration](docs/DataloopIOIntegration.md)
 - [DeprecatedAutoCloseAlertPolicy](docs/DeprecatedAutoCloseAlertPolicy.md)
 - [DeprecatedAutoRestartNotificationsAlertPolicy](docs/DeprecatedAutoRestartNotificationsAlertPolicy.md)
 - [DeprecatedCreateAlertPolicyResponse](docs/DeprecatedCreateAlertPolicyResponse.md)
 - [DeprecatedGetAlertPolicyResponse](docs/DeprecatedGetAlertPolicyResponse.md)
 - [DeprecatedListAlertPoliciesResponse](docs/DeprecatedListAlertPoliciesResponse.md)
 - [DeprecatedModifyAlertPolicy](docs/DeprecatedModifyAlertPolicy.md)
 - [DeprecatedNotificationDeduplicationAlertPolicy](docs/DeprecatedNotificationDeduplicationAlertPolicy.md)
 - [DeprecatedNotificationDelayAlertPolicy](docs/DeprecatedNotificationDelayAlertPolicy.md)
 - [DeprecatedNotificationRenotifyAlertPolicy](docs/DeprecatedNotificationRenotifyAlertPolicy.md)
 - [DeprecatedNotificationSuppressAlertPolicy](docs/DeprecatedNotificationSuppressAlertPolicy.md)
 - [DeskIntegration](docs/DeskIntegration.md)
 - [DetectifyIntegration](docs/DetectifyIntegration.md)
 - [DisableHeartbeatResponse](docs/DisableHeartbeatResponse.md)
 - [DisableIntegrationResponse](docs/DisableIntegrationResponse.md)
 - [DnsCheckIntegration](docs/DnsCheckIntegration.md)
 - [DripStatIntegration](docs/DripStatIntegration.md)
 - [DynatraceAppMonIntegration](docs/DynatraceAppMonIntegration.md)
 - [DynatraceIntegration](docs/DynatraceIntegration.md)
 - [DynatraceV2Integration](docs/DynatraceV2Integration.md)
 - [EmailBasedIncomingFeature](docs/EmailBasedIncomingFeature.md)
 - [EmailIntegration](docs/EmailIntegration.md)
 - [EnableHeartbeatResponse](docs/EnableHeartbeatResponse.md)
 - [EnableIntegrationResponse](docs/EnableIntegrationResponse.md)
 - [ErrorResponse](docs/ErrorResponse.md)
 - [ErrorceptionIntegration](docs/ErrorceptionIntegration.md)
 - [EscalateAlertToNextPayload](docs/EscalateAlertToNextPayload.md)
 - [EscalationRecipient](docs/EscalationRecipient.md)
 - [EvidentIOIntegration](docs/EvidentIOIntegration.md)
 - [ExecuteCustomAlertActionPayload](docs/ExecuteCustomAlertActionPayload.md)
 - [FlockIntegration](docs/FlockIntegration.md)
 - [FlowdockCallback](docs/FlowdockCallback.md)
 - [FlowdockIntegration](docs/FlowdockIntegration.md)
 - [FlowdockV2Callback](docs/FlowdockV2Callback.md)
 - [FlowdockV2Integration](docs/FlowdockV2Integration.md)
 - [FreshdeskIntegration](docs/FreshdeskIntegration.md)
 - [FreshserviceIntegration](docs/FreshserviceIntegration.md)
 - [GetAccountInfoResponse](docs/GetAccountInfoResponse.md)
 - [GetAlertAttachmentResponse](docs/GetAlertAttachmentResponse.md)
 - [GetAlertResponse](docs/GetAlertResponse.md)
 - [GetContactResponse](docs/GetContactResponse.md)
 - [GetCustomUserRoleResponse](docs/GetCustomUserRoleResponse.md)
 - [GetEscalationResponse](docs/GetEscalationResponse.md)
 - [GetForwardingRuleResponse](docs/GetForwardingRuleResponse.md)
 - [GetHeartbeatResponse](docs/GetHeartbeatResponse.md)
 - [GetIntegrationResponse](docs/GetIntegrationResponse.md)
 - [GetMaintenanceResponse](docs/GetMaintenanceResponse.md)
 - [GetNextOnCallResponse](docs/GetNextOnCallResponse.md)
 - [GetNotificationRuleResponse](docs/GetNotificationRuleResponse.md)
 - [GetNotificationRuleStepResponse](docs/GetNotificationRuleStepResponse.md)
 - [GetOnCallResponse](docs/GetOnCallResponse.md)
 - [GetPolicyResponse](docs/GetPolicyResponse.md)
 - [GetRequestStatusResponse](docs/GetRequestStatusResponse.md)
 - [GetSavedSearchResponse](docs/GetSavedSearchResponse.md)
 - [GetScheduleOverrideResponse](docs/GetScheduleOverrideResponse.md)
 - [GetScheduleResponse](docs/GetScheduleResponse.md)
 - [GetScheduleRotationResponse](docs/GetScheduleRotationResponse.md)
 - [GetTeamResponse](docs/GetTeamResponse.md)
 - [GetTeamRoleResponse](docs/GetTeamRoleResponse.md)
 - [GetTeamRoutingRuleResponse](docs/GetTeamRoutingRuleResponse.md)
 - [GhostInspectorIntegration](docs/GhostInspectorIntegration.md)
 - [GitHubIntegration](docs/GitHubIntegration.md)
 - [GitLabIntegration](docs/GitLabIntegration.md)
 - [GoogleStackDriverIntegration](docs/GoogleStackDriverIntegration.md)
 - [GrafanaIntegration](docs/GrafanaIntegration.md)
 - [GrafanaV2Integration](docs/GrafanaV2Integration.md)
 - [GraylogIntegration](docs/GraylogIntegration.md)
 - [GroupRecipient](docs/GroupRecipient.md)
 - [HPServiceManagerIntegration](docs/HPServiceManagerIntegration.md)
 - [HeartbeatIntegration](docs/HeartbeatIntegration.md)
 - [HipChatAddOnIntegration](docs/HipChatAddOnIntegration.md)
 - [HipChatIntegration](docs/HipChatIntegration.md)
 - [HipChatIntegrationV2](docs/HipChatIntegrationV2.md)
 - [HoneybadgerIntegration](docs/HoneybadgerIntegration.md)
 - [HostedGraphiteIntegration](docs/HostedGraphiteIntegration.md)
 - [HumioIntegration](docs/HumioIntegration.md)
 - [Icinga2Integration](docs/Icinga2Integration.md)
 - [IcingaIntegration](docs/IcingaIntegration.md)
 - [IgnoreIntegrationAction](docs/IgnoreIntegrationAction.md)
 - [IncomingCallIntegration](docs/IncomingCallIntegration.md)
 - [InstanaIntegration](docs/InstanaIntegration.md)
 - [JenkinsIntegration](docs/JenkinsIntegration.md)
 - [JiraIntegration](docs/JiraIntegration.md)
 - [JiraServiceDeskIntegration](docs/JiraServiceDeskIntegration.md)
 - [KapacitorIntegration](docs/KapacitorIntegration.md)
 - [KayakoIntegration](docs/KayakoIntegration.md)
 - [KoreIntegration](docs/KoreIntegration.md)
 - [LabTechEmailIntegration](docs/LabTechEmailIntegration.md)
 - [LibratoIntegration](docs/LibratoIntegration.md)
 - [LibreNMSIntegration](docs/LibreNMSIntegration.md)
 - [LightstepIntegration](docs/LightstepIntegration.md)
 - [ListAlertAttachmentsResponse](docs/ListAlertAttachmentsResponse.md)
 - [ListAlertLogsResponse](docs/ListAlertLogsResponse.md)
 - [ListAlertNotesResponse](docs/ListAlertNotesResponse.md)
 - [ListAlertRecipientsResponse](docs/ListAlertRecipientsResponse.md)
 - [ListAlertsResponse](docs/ListAlertsResponse.md)
 - [ListContactsResponse](docs/ListContactsResponse.md)
 - [ListCustomUserRolesResponse](docs/ListCustomUserRolesResponse.md)
 - [ListEscalationsResponse](docs/ListEscalationsResponse.md)
 - [ListForwardingRulesResponse](docs/ListForwardingRulesResponse.md)
 - [ListIntegrationActionsResponse](docs/ListIntegrationActionsResponse.md)
 - [ListIntegrationsResponse](docs/ListIntegrationsResponse.md)
 - [ListMaintenanceResponse](docs/ListMaintenanceResponse.md)
 - [ListNotificationRuleStepsResponse](docs/ListNotificationRuleStepsResponse.md)
 - [ListNotificationRulesResponse](docs/ListNotificationRulesResponse.md)
 - [ListOnCallsResponse](docs/ListOnCallsResponse.md)
 - [ListPoliciesResponse](docs/ListPoliciesResponse.md)
 - [ListSavedSearchesResponse](docs/ListSavedSearchesResponse.md)
 - [ListScheduleOverrideResponse](docs/ListScheduleOverrideResponse.md)
 - [ListScheduleRotationsResponse](docs/ListScheduleRotationsResponse.md)
 - [ListTeamLogsResponse](docs/ListTeamLogsResponse.md)
 - [ListTeamRoleResponse](docs/ListTeamRoleResponse.md)
 - [ListTeamRoutingRulesResponse](docs/ListTeamRoutingRulesResponse.md)
 - [ListUserEscalationsResponse](docs/ListUserEscalationsResponse.md)
 - [ListUserForwardingRulesResponse](docs/ListUserForwardingRulesResponse.md)
 - [ListUserSchedulesResponse](docs/ListUserSchedulesResponse.md)
 - [ListUserTeamsResponse](docs/ListUserTeamsResponse.md)
 - [ListUsersResponse](docs/ListUsersResponse.md)
 - [LogentriesIntegration](docs/LogentriesIntegration.md)
 - [LogglyIntegration](docs/LogglyIntegration.md)
 - [LogicMonitorIntegration](docs/LogicMonitorIntegration.md)
 - [LogstashIntegration](docs/LogstashIntegration.md)
 - [LogzIOIntegration](docs/LogzIOIntegration.md)
 - [LookerIntegration](docs/LookerIntegration.md)
 - [LoomIntegration](docs/LoomIntegration.md)
 - [MSTeamsIntegration](docs/MSTeamsIntegration.md)
 - [MSTeamsV2Integration](docs/MSTeamsV2Integration.md)
 - [MagentrixIntegration](docs/MagentrixIntegration.md)
 - [ManageEngineIntegrationDTO](docs/ManageEngineIntegrationDTO.md)
 - [MaridIntegration](docs/MaridIntegration.md)
 - [MatchAll](docs/MatchAll.md)
 - [MatchAllConditions](docs/MatchAllConditions.md)
 - [MatchAnyCondition](docs/MatchAnyCondition.md)
 - [MattermostIntegration](docs/MattermostIntegration.md)
 - [MongoDBCloudIntegration](docs/MongoDBCloudIntegration.md)
 - [MonitisEmailIntegration](docs/MonitisEmailIntegration.md)
 - [MonitisIntegration](docs/MonitisIntegration.md)
 - [MoxtraIntegration](docs/MoxtraIntegration.md)
 - [NagiosIntegrationV1](docs/NagiosIntegrationV1.md)
 - [NagiosIntegrationV2](docs/NagiosIntegrationV2.md)
 - [NagiosXIIntegrationV1](docs/NagiosXIIntegrationV1.md)
 - [NagiosXIIntegrationV2](docs/NagiosXIIntegrationV2.md)
 - [NetuitiveIntegration](docs/NetuitiveIntegration.md)
 - [NeustarIntegration](docs/NeustarIntegration.md)
 - [NewRelicIntegration](docs/NewRelicIntegration.md)
 - [NewRelicV2Integration](docs/NewRelicV2Integration.md)
 - [NoRecipient](docs/NoRecipient.md)
 - [NodePingIntegration](docs/NodePingIntegration.md)
 - [NotificationPolicy](docs/NotificationPolicy.md)
 - [OEMEmailIntegration](docs/OEMEmailIntegration.md)
 - [OEMIntegration](docs/OEMIntegration.md)
 - [OP5Integration](docs/OP5Integration.md)
 - [ObserviumIntegration](docs/ObserviumIntegration.md)
 - [ObserviumV2Integration](docs/ObserviumV2Integration.md)
 - [OpsDashIntegration](docs/OpsDashIntegration.md)
 - [OpsGenieIntegration](docs/OpsGenieIntegration.md)
 - [OpsviewIntegration](docs/OpsviewIntegration.md)
 - [PagerDutyCompatibilityIntegration](docs/PagerDutyCompatibilityIntegration.md)
 - [PanoptaIntegration](docs/PanoptaIntegration.md)
 - [PapertrailIntegration](docs/PapertrailIntegration.md)
 - [PingdomIntegration](docs/PingdomIntegration.md)
 - [PingdomV2Integration](docs/PingdomV2Integration.md)
 - [PingdomWebhookIntegration](docs/PingdomWebhookIntegration.md)
 - [PingometerIntegration](docs/PingometerIntegration.md)
 - [PlanioCallback](docs/PlanioCallback.md)
 - [PlanioIntegration](docs/PlanioIntegration.md)
 - [PrometheusIntegration](docs/PrometheusIntegration.md)
 - [PrtgIntegration](docs/PrtgIntegration.md)
 - [RackspaceIntegration](docs/RackspaceIntegration.md)
 - [RaygunIntegration](docs/RaygunIntegration.md)
 - [RedGateSqlMonitorEmailIntegration](docs/RedGateSqlMonitorEmailIntegration.md)
 - [RiemannIntegration](docs/RiemannIntegration.md)
 - [RigorIntegration](docs/RigorIntegration.md)
 - [RingCentralEmailIntegration](docs/RingCentralEmailIntegration.md)
 - [RingCentralGlipIntegration](docs/RingCentralGlipIntegration.md)
 - [RollbarIntegration](docs/RollbarIntegration.md)
 - [RunscopeIntegration](docs/RunscopeIntegration.md)
 - [SalesForceServiceCloudIntegration](docs/SalesForceServiceCloudIntegration.md)
 - [SaltStackIntegration](docs/SaltStackIntegration.md)
 - [ScalyrIntegration](docs/ScalyrIntegration.md)
 - [ScheduleRecipient](docs/ScheduleRecipient.md)
 - [ScheduleRotationWithParent](docs/ScheduleRotationWithParent.md)
 - [ScomIntegration](docs/ScomIntegration.md)
 - [ScoutIntegration](docs/ScoutIntegration.md)
 - [SematextSpmIntegration](docs/SematextSpmIntegration.md)
 - [SensuIntegration](docs/SensuIntegration.md)
 - [SentryIntegration](docs/SentryIntegration.md)
 - [ServerDensityIntegration](docs/ServerDensityIntegration.md)
 - [ServerGuard24Integration](docs/ServerGuard24Integration.md)
 - [ServiceNowIntegration](docs/ServiceNowIntegration.md)
 - [ServiceNowV2Integration](docs/ServiceNowV2Integration.md)
 - [ServiceNowV3Integration](docs/ServiceNowV3Integration.md)
 - [SignalSciencesIntegration](docs/SignalSciencesIntegration.md)
 - [SignalfxIntegration](docs/SignalfxIntegration.md)
 - [Site24x7Integration](docs/Site24x7Integration.md)
 - [SlackAppIntegration](docs/SlackAppIntegration.md)
 - [SlackIntegration](docs/SlackIntegration.md)
 - [SnoozeAlertPayload](docs/SnoozeAlertPayload.md)
 - [SoastaIntegration](docs/SoastaIntegration.md)
 - [SolarWindsWebHelpDeskIntegration](docs/SolarWindsWebHelpDeskIntegration.md)
 - [SolarwindsIntegration](docs/SolarwindsIntegration.md)
 - [SolarwindsMSPNCentralIntegration](docs/SolarwindsMSPNCentralIntegration.md)
 - [SplunkITSIIntegration](docs/SplunkITSIIntegration.md)
 - [SplunkIntegration](docs/SplunkIntegration.md)
 - [StackStormIntegration](docs/StackStormIntegration.md)
 - [StackdriverIntegration](docs/StackdriverIntegration.md)
 - [StatusCakeIntegration](docs/StatusCakeIntegration.md)
 - [StatusHubIntegration](docs/StatusHubIntegration.md)
 - [StatusIOIntegration](docs/StatusIOIntegration.md)
 - [StatusPageIOIntegration](docs/StatusPageIOIntegration.md)
 - [StatusyIntegration](docs/StatusyIntegration.md)
 - [StruxureWareIntegration](docs/StruxureWareIntegration.md)
 - [SuccessResponse](docs/SuccessResponse.md)
 - [SumoLogicIntegration](docs/SumoLogicIntegration.md)
 - [SysdigCloudIntegration](docs/SysdigCloudIntegration.md)
 - [TeamRecipient](docs/TeamRecipient.md)
 - [TeamResponder](docs/TeamResponder.md)
 - [ThousandEyesIntegration](docs/ThousandEyesIntegration.md)
 - [ThreatStackIntegration](docs/ThreatStackIntegration.md)
 - [TidewaysIntegration](docs/TidewaysIntegration.md)
 - [TimeOfDayRestrictionInterval](docs/TimeOfDayRestrictionInterval.md)
 - [TokenBasedIncomingFeature](docs/TokenBasedIncomingFeature.md)
 - [TraceIntegration](docs/TraceIntegration.md)
 - [TrackItIntegration](docs/TrackItIntegration.md)
 - [TravisCIIntegration](docs/TravisCIIntegration.md)
 - [TwilioIntegration](docs/TwilioIntegration.md)
 - [UnAcknowledgeAlertPayload](docs/UnAcknowledgeAlertPayload.md)
 - [UpdateHeartbeatResponse](docs/UpdateHeartbeatResponse.md)
 - [UpdateIntegrationActionsResponse](docs/UpdateIntegrationActionsResponse.md)
 - [UpdateIntegrationResponse](docs/UpdateIntegrationResponse.md)
 - [UpdateMaintenanceResponse](docs/UpdateMaintenanceResponse.md)
 - [UpdateNotificationRuleResponse](docs/UpdateNotificationRuleResponse.md)
 - [UpdateScheduleOverrideResponse](docs/UpdateScheduleOverrideResponse.md)
 - [UpdateScheduleResponse](docs/UpdateScheduleResponse.md)
 - [UpdownIOIntegration](docs/UpdownIOIntegration.md)
 - [UptimeRobotEmailIntegration](docs/UptimeRobotEmailIntegration.md)
 - [UptimeRobotIntegration](docs/UptimeRobotIntegration.md)
 - [UptimeWebhookIntegration](docs/UptimeWebhookIntegration.md)
 - [UptrendsEmailIntegration](docs/UptrendsEmailIntegration.md)
 - [UserRecipient](docs/UserRecipient.md)
 - [UserResponder](docs/UserResponder.md)
 - [VCSAIntegration](docs/VCSAIntegration.md)
 - [VCenterIntegration](docs/VCenterIntegration.md)
 - [WavefrontIntegration](docs/WavefrontIntegration.md)
 - [WebhookIntegration](docs/WebhookIntegration.md)
 - [WeekdayTimeRestrictionInterval](docs/WeekdayTimeRestrictionInterval.md)
 - [WhatsUpGoldIntegration](docs/WhatsUpGoldIntegration.md)
 - [WorkatoIntegration](docs/WorkatoIntegration.md)
 - [XLReleaseIntegration](docs/XLReleaseIntegration.md)
 - [XPackAlertingIntegration](docs/XPackAlertingIntegration.md)
 - [XmppIntegration](docs/XmppIntegration.md)
 - [ZabbixIntegration](docs/ZabbixIntegration.md)
 - [ZapierIntegration](docs/ZapierIntegration.md)
 - [ZendeskIntegration](docs/ZendeskIntegration.md)
 - [ZenossIntegration](docs/ZenossIntegration.md)
 - [ZyrionIntegration](docs/ZyrionIntegration.md)
 - [AckIntegrationAction](docs/AckIntegrationAction.md)
 - [AddNoteIntegrationAction](docs/AddNoteIntegrationAction.md)
 - [BMCFootPrintsV11Callback](docs/BMCFootPrintsV11Callback.md)
 - [BMCFootPrintsV12Callback](docs/BMCFootPrintsV12Callback.md)
 - [BMCRemedyCallback](docs/BMCRemedyCallback.md)
 - [CherwellCallback](docs/CherwellCallback.md)
 - [CirconusCallback](docs/CirconusCallback.md)
 - [CloseIntegrationAction](docs/CloseIntegrationAction.md)
 - [ConnectWiseCallback](docs/ConnectWiseCallback.md)
 - [ConnectWiseManageCallback](docs/ConnectWiseManageCallback.md)
 - [ConnectWiseManageV2Callback](docs/ConnectWiseManageV2Callback.md)
 - [CreateIntegrationAction](docs/CreateIntegrationAction.md)
 - [DatadogCallback](docs/DatadogCallback.md)
 - [DeskCallback](docs/DeskCallback.md)
 - [DynatraceAppMonCallback](docs/DynatraceAppMonCallback.md)
 - [FlockCallback](docs/FlockCallback.md)
 - [FreshdeskCallback](docs/FreshdeskCallback.md)
 - [FreshserviceCallback](docs/FreshserviceCallback.md)
 - [GetScheduleTimelineResponse](docs/GetScheduleTimelineResponse.md)
 - [GetUserResponse](docs/GetUserResponse.md)
 - [HipChatAddOnCallback](docs/HipChatAddOnCallback.md)
 - [HipChatCallbackV2](docs/HipChatCallbackV2.md)
 - [Icinga2Callback](docs/Icinga2Callback.md)
 - [IcingaCallback](docs/IcingaCallback.md)
 - [JiraCallback](docs/JiraCallback.md)
 - [JiraServiceDeskCallback](docs/JiraServiceDeskCallback.md)
 - [KayakoCallback](docs/KayakoCallback.md)
 - [KoreCallback](docs/KoreCallback.md)
 - [LibreNMSCallback](docs/LibreNMSCallback.md)
 - [ListSchedulesResponse](docs/ListSchedulesResponse.md)
 - [ListTeamsResponse](docs/ListTeamsResponse.md)
 - [LogicMonitorCallback](docs/LogicMonitorCallback.md)
 - [MSTeamsCallback](docs/MSTeamsCallback.md)
 - [MSTeamsV2Callback](docs/MSTeamsV2Callback.md)
 - [MagentrixCallback](docs/MagentrixCallback.md)
 - [MaridCallback](docs/MaridCallback.md)
 - [MattermostCallback](docs/MattermostCallback.md)
 - [MoxtraCallback](docs/MoxtraCallback.md)
 - [NagiosBasedV1Callback](docs/NagiosBasedV1Callback.md)
 - [NagiosBasedV2Callback](docs/NagiosBasedV2Callback.md)
 - [NagiosXIV1Callback](docs/NagiosXIV1Callback.md)
 - [NagiosXIV2Callback](docs/NagiosXIV2Callback.md)
 - [OP5Callback](docs/OP5Callback.md)
 - [OpsGenieCallback](docs/OpsGenieCallback.md)
 - [PrtgCallback](docs/PrtgCallback.md)
 - [RingCentralGlipCallback](docs/RingCentralGlipCallback.md)
 - [RollbarCallback](docs/RollbarCallback.md)
 - [SalesForceServiceCloudCallback](docs/SalesForceServiceCloudCallback.md)
 - [ServiceNowV2Callback](docs/ServiceNowV2Callback.md)
 - [ServiceNowV3Callback](docs/ServiceNowV3Callback.md)
 - [SlackAppCallback](docs/SlackAppCallback.md)
 - [SlackCallback](docs/SlackCallback.md)
 - [SolarWindsWebHelpDeskCallback](docs/SolarWindsWebHelpDeskCallback.md)
 - [SolarwindsCallback](docs/SolarwindsCallback.md)
 - [SolarwindsMSPNcentralCallback](docs/SolarwindsMSPNcentralCallback.md)
 - [SplunkITSICallback](docs/SplunkITSICallback.md)
 - [StackdriverCallback](docs/StackdriverCallback.md)
 - [StatusIOCallback](docs/StatusIOCallback.md)
 - [StatusPageIOCallback](docs/StatusPageIOCallback.md)
 - [StatusyCallback](docs/StatusyCallback.md)
 - [SumoLogicCallback](docs/SumoLogicCallback.md)
 - [TrackItCallback](docs/TrackItCallback.md)
 - [WebhookCallback](docs/WebhookCallback.md)
 - [XPackAlertingCallback](docs/XPackAlertingCallback.md)
 - [XmppCallback](docs/XmppCallback.md)
 - [ZabbixCallback](docs/ZabbixCallback.md)
 - [ZendeskCallback](docs/ZendeskCallback.md)
 - [ZenossCallback](docs/ZenossCallback.md)


## Documentation For Authorization


## GenieKey

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## Author



